entrypoints: Discover and load entry points from installed Python packages
==========================================================================

Description
-----------

Discover and load entry points from installed packages.


Upstream Contact
----------------

https://github.com/takluyver/entrypoints


Special Update/Build Instructions
---------------------------------

Upstream does not provide a source tarball, so the tarball was taken
from github and renamed.

The source tarball does not contain setup.py, so we put the setup
commands in spkg-install.
